@@ -148,6 +148,11 @@ sub _call {
         $form_type    => $request->parameters,
     );
 
+    if (my $error = $tx->req->error) {
+        $self->logger->warn('No HTTP code was received from Mattermost. Is your server alive?');
+        $self->logger->warnf('The following may be useful: %s', $error->{message});
+    }
+
     return $self->_as_response($tx->res, $args);
 }
 
@@ -177,14 +182,6 @@ sub _as_response {
         $view_name = $args->{view};
     }
 
-    unless ($res->code) {
-        $self->logger->warn('No HTTP code was received from Mattermost. Is your server alive?');
-
-        if ($res->message) {
-            $self->logger->warnf('The following may be useful: %s', $res->message);
-        }
-    }
-
     if ($res->is_error && $self->debug) {
         $self->logger->warnf('An API error occurred: %s', $res->message);
     }
@@ -258,7 +255,7 @@ WebService::Mattermost::V4::API::Resource - Base class for API resources.
 
 =head1 VERSION
 
-version 0.25
+version 0.26
 
 =head1 DESCRIPTION
 
